Unlike GitHub & most SaaS platforms, LaminHub by default neither hosts data nor metadata, but connects to distributed storage locations & databases through LaminDB. Public demo instances to explore in the UI or load using the CLI via `lamin load owner/instance` (you need an account): - [lamin.ai/laminlabs/lamindata](https://lamin.ai/laminlabs/lamindata) - a larger instance using Postgres & multiple private storage locations - [lamin.ai/laminlabs/cellxgene-census](https://lamin.ai/laminlabs/cellxgene-census) - query cellxgene-census using LaminDB ([guide](docs:cellxgene-census)) - [lamin.ai/laminlabs/lamin-site-assets](https://lamin.ai/laminlabs/lamin-site-assets) - explore Lamin's static website assets

See validated files & arrays in context of ontologies & experimental metadata:

Track data flow through pipelines, notebooks & UI:

Upload & register files:

Browse files: